@@ -2,7 +2,7 @@ import unittest
 import os
 import overrides_hack
 
-from utils import run, create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, TestTags, tag_test
+from utils import run, create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, TestTags, tag_test, required_plugins
 
 import gi
 gi.require_version('GLib', '2.0')
@@ -10,6 +10,7 @@ gi.require_version('BlockDev', '3.0')
 from gi.repository import GLib, BlockDev
 
 
+@required_plugins(("dm",))
 class DevMapperTest(unittest.TestCase):
 
     requested_plugins = BlockDev.plugin_specs_from_names(("dm",))
