@@ -33,7 +33,7 @@ def check_output(args, ignore_retcode=True):
         else:
             raise
 
-
+@utils.required_plugins(("fs", "loop"))
 class FSNoDevTestCase(unittest.TestCase):
 
     requested_plugins = BlockDev.plugin_specs_from_names(("fs", "loop"))
@@ -61,6 +61,9 @@ class FSNoDevTestCase(unittest.TestCase):
         except:
             cls.f2fs_avail = False
 
+        if not BlockDev.utils_have_kernel_module("f2fs"):
+            cls.f2fs_avail = False
+
         try:
             cls.nilfs2_avail = BlockDev.fs_is_tech_avail(BlockDev.FSTech.NILFS2,
                                                          BlockDev.FSTechMode.MKFS |
@@ -69,6 +72,9 @@ class FSNoDevTestCase(unittest.TestCase):
         except:
             cls.nilfs2_avail = False
 
+        if not BlockDev.utils_have_kernel_module("nilfs2"):
+            cls.nilfs2_avail = False
+
         try:
             cls.exfat_avail = BlockDev.fs_is_tech_avail(BlockDev.FSTech.EXFAT,
                                                         BlockDev.FSTechMode.MKFS |
@@ -88,6 +94,9 @@ class FSNoDevTestCase(unittest.TestCase):
         except:
             cls.btrfs_avail = False
 
+        if not BlockDev.utils_have_kernel_module("btrfs"):
+            cls.btrfs_avail = False
+
         try:
             cls.udf_avail = BlockDev.fs_is_tech_avail(BlockDev.FSTech.UDF,
                                                       BlockDev.FSTechMode.MKFS |
