@@ -3,13 +3,15 @@ import os
 import overrides_hack
 import shutil
 
-from utils import create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, get_version, TestTags, tag_test
+from utils import create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, get_version, TestTags, tag_test, required_plugins
 
 import gi
 gi.require_version('GLib', '2.0')
 gi.require_version('BlockDev', '3.0')
 from gi.repository import GLib, BlockDev
 
+
+@required_plugins(("mpath",))
 class MpathTest(unittest.TestCase):
 
     requested_plugins = BlockDev.plugin_specs_from_names(("mpath",))
